@@ -59,6 +59,8 @@
 #' # summarize jenks breaks, 3x3
 #' table(data$bi_class)
 #'
+#' @import sf
+#'
 #' @export
 bi_class <- function(.data, x, y, style = "quantile", dim = 3, keep_factors = FALSE){
 
@@ -70,6 +72,12 @@ bi_class <- function(.data, x, y, style = "quantile", dim = 3, keep_factors = FA
     stop("An object containing data must be specified for the '.data' argument.")
   }
 
+  # check data
+#  if ("sf" %in% class(.data) == TRUE & "sf" %in% (.packages()) == FALSE){
+#    warning("The 'sf' package is not loaded, and the class 'sf' attribute of the given data set has been lost. Load 'sf' to retain the class when using 'bi_class'.")
+#  }
+
+  # check inputs
   if (missing(x)) {
     stop("A variable must be given for the 'x' argument.")
   }
@@ -94,11 +102,6 @@ bi_class <- function(.data, x, y, style = "quantile", dim = 3, keep_factors = FA
     stop("A logical scalar must be supplied for 'keep_factors'. Please provide either 'TRUE' or 'FALSE'.")
   }
 
-  # check data
-  if ("sf" %in% class(.data) == TRUE & "sf" %in% (.packages()) == FALSE){
-    warning("The 'sf' package is not loaded, and the class 'sf' attribute of the given data set has been lost. Load 'sf' to retain the class when using 'bi_class'.")
-  }
-
   # save parameters to list
   paramList <- as.list(match.call())
 
